
.. If you created a package, create one automodule per module in the package.

.. automodule:: circuitpython_uplot.uplot
    :members:

.. automodule:: circuitpython_uplot.uscatter
    :members:

.. automodule:: circuitpython_uplot.ubar
    :members:

.. automodule:: circuitpython_uplot.upie
    :members:

.. automodule:: circuitpython_uplot.ucartesian
    :members:

.. automodule:: circuitpython_uplot.ufillbetween
    :members:

.. automodule:: circuitpython_uplot.umap
    :members:

.. automodule:: circuitpython_uplot.ulogging
    :members:
